filelock: A platform independent file lock
==========================================

Description
-----------

A platform independent file lock.

License
-------

Public Domain <http://unlicense.org>

Upstream Contact
----------------

https://pypi.org/project/filelock/

